@@ -1,16 +1,17 @@
-'''edit.py'''
-
 # Internal Libraries
 import os
 from typing import List, Tuple
 
+# External Libraries
 import numpy as np
 
-from auto_editor.utils.effects import Effect
+# Included Libraries
+from auto_editor.sheet import Sheet
 from auto_editor.utils.log import Log
 from auto_editor.utils.func import fnone, set_output_name, append_filename
 
-def get_chunks(inp, segment, fps, args, log, audio_samples=None, sample_rate=None):
+def get_chunks(inp, segment, fps, args, progress, log, audio_samples=None,
+    sample_rate=None):
     from auto_editor.cutting import (combine_audio_motion, combine_segment, to_speed_list,
         set_range, chunkify, apply_mark_as, apply_margin, seconds_to_frames, cook)
 
@@ -25,35 +26,35 @@ def get_chunks(inp, segment, fps, args, log, audio_samples=None, sample_rate=Non
         # type: (...) -> np.ndarray
         from auto_editor.analyze.generic import get_np_list
 
-        if(args.edit_based_on == 'none'):
-            return get_np_list(inp, audio_samples, sample_rate, fps, np.ones)
-        if(args.edit_based_on == 'all'):
-            return get_np_list(inp, audio_samples, sample_rate, fps, np.zeros)
+        if args.edit_based_on == 'none':
+            return get_np_list(inp.path, audio_samples, sample_rate, fps, np.ones)
+        if args.edit_based_on == 'all':
+            return get_np_list(inp.path, audio_samples, sample_rate, fps, np.zeros)
 
         audio_list, motion_list = None, None
 
-        if('audio' in args.edit_based_on):
+        if 'audio' in args.edit_based_on:
             from auto_editor.analyze.audio import audio_detection
 
-            if(audio_samples is None):
-                audio_list = get_np_list(inp, audio_samples, sample_rate, fps, np.ones)
+            if audio_samples is None:
+                audio_list = get_np_list(inp.path, audio_samples, sample_rate, fps, np.ones)
             else:
                 audio_list = audio_detection(audio_samples, sample_rate,
                     args.silent_threshold, fps, log)
 
-        if('motion' in args.edit_based_on):
+        if 'motion' in args.edit_based_on:
             from auto_editor.analyze.motion import motion_detection
 
-            if(len(inp.video_streams) == 0):
-                motion_list = get_np_list(inp, audio_samples, sample_rate, fps, np.ones)
+            if len(inp.video_streams) == 0:
+                motion_list = get_np_list(inp.path, audio_samples, sample_rate, fps, np.ones)
             else:
-                motion_list = motion_detection(inp, args.motion_threshold, log,
-                    width=args.md_width, dilates=args.md_dilates, blur=args.md_blur)
+                motion_list = motion_detection(inp.path, fps, args.motion_threshold,
+                    progress, args.md_width, args.md_blur)
 
-        if(audio_list is not None and motion_list is not None):
-            if(len(audio_list) > len(motion_list)):
+        if audio_list is not None and motion_list is not None:
+            if len(audio_list) > len(motion_list):
                 audio_list = audio_list[:len(motion_list)]
-            elif(len(motion_list) > len(audio_list)):
+            elif len(motion_list) > len(audio_list):
                 motion_list = motion_list[:len(audio_list)]
 
         return combine_audio_motion(audio_list, motion_list, args.edit_based_on, log)
@@ -90,16 +91,16 @@ def edit_media(i, inp, ffmpeg, args, progress, segment, exporting_to_editor, dat
     from auto_editor.utils.container import get_rules
 
     chunks = None
-    if(inp.ext == '.json'):
-        from auto_editor.formats.make_json import read_json_cutlist
+    if inp.ext == '.json':
+        from auto_editor.formats.timeline import read_json_timeline
 
-        input_path, chunks = read_json_cutlist(inp.path, log)
+        args.background, input_path, chunks = read_json_timeline(inp.path, log)
         inp = ffmpeg.file_info(input_path)
 
         output_path = set_output_name(inp.path, inp.ext, data_file, args)
     else:
         output_path = args.output_file[i]
-        if(not os.path.isdir(inp.path) and os.path.splitext(output_path)[1] == ''):
+        if not os.path.isdir(inp.path) and os.path.splitext(output_path)[1] == '':
             output_path = set_output_name(output_path, inp.ext, data_file, args)
 
     log.debug('{} -> {}'.format(inp.path, output_path))
@@ -152,14 +153,8 @@ def edit_media(i, inp, ffmpeg, args, progress, segment, exporting_to_editor, dat
 
     audio_samples = None
     tracks = len(inp.audio_streams)
-    audio_file = len(inp.video_streams) == 0 and tracks == 1
 
-    if(inp.fps is None):
-        fps = 30
-    elif(exporting_to_editor):
-        fps = int(float(inp.fps))
-    else:
-        fps = float(inp.fps)
+    fps = 30 if inp.fps is None else float(inp.fps)
 
     if(fps < 1):
         log.error('{}: Frame rate cannot be below 1. fps: {}'.format(inp.basename, fps))
@@ -175,7 +170,7 @@ def edit_media(i, inp, ffmpeg, args, progress, segment, exporting_to_editor, dat
 
     sample_rate = None
 
-    if(args.cut_by_this_track >= tracks and 'cut_by_this_track' in args._set):
+    if args.cut_by_this_track >= tracks and args.cut_by_this_track != 0:
         message = "You choose a track that doesn't exist.\nThere "
         if(tracks == 1):
             message += 'is only {} track.\n'.format(tracks)
@@ -185,42 +180,16 @@ def edit_media(i, inp, ffmpeg, args, progress, segment, exporting_to_editor, dat
             message += ' Track {}\n'.format(t)
         log.error(message)
 
-    def number_of_VFR_frames(text, log):
-        import re
-        search = re.search(r'VFR:[\d.]+ \(\d+\/\d+\)', text, re.M)
-        if(search is None):
-            log.warning('Could not get number of VFR Frames.')
-            return 0
-        else:
-            nums = re.search(r'\d+\/\d+', search.group()).group(0)
-            log.debug('VFR Frames: {}'.format(nums))
-            return int(nums.split('/')[0])
-
-    def has_VFR(cmd, log):
-        return number_of_VFR_frames(ffmpeg.pipe(cmd), log) != 0
-
     # Split audio tracks into: 0.wav, 1.wav, etc.
+    log.conwrite('Extracting audio')
+
     cmd = ['-i', inp.path, '-hide_banner']
     for t in range(tracks):
         cmd.extend(['-map', '0:a:{}'.format(t), '-ac', '2',
             os.path.join(temp, '{}.wav'.format(t))])
-    cmd.extend(['-map', '0:v:0'])
-    if(args.has_vfr == 'unset' and len(inp.video_streams) > 0 and not args.preview):
-        log.conwrite('Extracting audio / detecting VFR')
-        cmd.extend(['-vf', 'vfrdet', '-f', 'null', '-'])
-        has_vfr = has_VFR(cmd, log)
-    else:
-        log.conwrite('Extracting audio')
-        ffmpeg.run(cmd)
-        has_vfr = args.has_vfr == 'yes'
+    ffmpeg.run(cmd)
     del cmd
 
-    if(len(inp.video_streams) > 0 and tracks == 0):
-        # Doesn't matter because we don't need to align to an audio track.
-        has_vfr = False
-
-    log.debug('Has VFR: {}'.format(has_vfr))
-
     if(tracks != 0):
         if(args.cut_by_all_tracks):
             temp_file = os.path.join(temp, 'combined.wav')
@@ -235,9 +204,12 @@ def edit_media(i, inp, ffmpeg, args, progress, segment, exporting_to_editor, dat
         from auto_editor.scipy.wavfile import read
         sample_rate, audio_samples = read(temp_file)
 
-    log.debug('Frame Rate: {}'.format(fps))
-    if(chunks is None):
-        chunks = get_chunks(inp, segment, fps, args, log, audio_samples, sample_rate)
+    if chunks is None:
+        chunks = get_chunks(inp, segment, fps, args, progress, log, audio_samples,
+            sample_rate)
+
+    if len(chunks) == 1 and chunks[0][2] == 99999:
+        log.error('The entire media is cut!')
 
     def is_clip(chunk: Tuple[int, int, float]) -> bool:
         return chunk[2] != 99999
@@ -246,27 +218,22 @@ def edit_media(i, inp, ffmpeg, args, progress, segment, exporting_to_editor, dat
         # type: (List[Tuple[int, int, float]]) -> int
         return len(list(filter(is_clip, chunks)))
 
-    def get_clips(chunks):
-        # type: (List[Tuple[int, int, float]]) -> List[List[int, int, float]]
-        clips = []
-        for chunk in chunks:
-            if(is_clip(chunk)):
-                clips.append([chunk[0], chunk[1], chunk[2] * 100])
-        return clips
-
     num_cuts = number_of_cuts(chunks)
-    clips = get_clips(chunks)
 
-    effects = Effect(args, log, _vars={})
+
+    pool = args.add_text + args.add_rectangle + args.add_ellipse + args.add_image
+
+    obj_sheet = Sheet(pool, inp, chunks, log)
 
     if(args.export_as_json):
-        from auto_editor.formats.make_json import make_json_cutlist
-        make_json_cutlist(inp.path, output_path, chunks, log)
+        from auto_editor.formats.timeline import make_json_timeline
+        make_json_timeline(inp.path, output_path, obj_sheet, chunks, fps, args.background,
+            log)
         return num_cuts, output_path
 
     if(args.timeline):
-        from auto_editor.formats.make_json import make_json_cutlist
-        make_json_cutlist(inp.path, 0, chunks, log)
+        from auto_editor.formats.timeline import make_json_timeline
+        make_json_timeline(inp.path, 0, obj_sheet, chunks, fps, args.background, log)
         return num_cuts, None
 
     if(args.preview):
@@ -276,21 +243,19 @@ def edit_media(i, inp, ffmpeg, args, progress, segment, exporting_to_editor, dat
 
     if(args.export_to_premiere):
         from auto_editor.formats.premiere import premiere_xml
-        premiere_xml(inp, temp, output_path, clips, chunks, sample_rate, audio_file,
-            fps, log)
+        premiere_xml(inp, temp, output_path, chunks, sample_rate, fps, log)
         return num_cuts, output_path
 
     if(args.export_to_final_cut_pro):
         from auto_editor.formats.final_cut_pro import fcp_xml
 
-        total_frames = chunks[len(chunks) - 1][1]
-        fcp_xml(inp, temp, output_path, clips, tracks, total_frames, audio_file, fps, log)
+        fcp_xml(inp, temp, output_path, chunks, fps, log)
         return num_cuts, output_path
 
     if(args.export_to_shotcut):
         from auto_editor.formats.shotcut import shotcut_xml
 
-        shotcut_xml(inp, temp, output_path, clips, chunks, fps, log)
+        shotcut_xml(inp, temp, output_path, chunks, fps, log)
         return num_cuts, output_path
 
     def pad_chunk(item, total_frames):
@@ -335,7 +300,7 @@ def edit_media(i, inp, ffmpeg, args, progress, segment, exporting_to_editor, dat
                     video_stuff.append(('image', None, None))
                 else:
                     video_stuff.append(render_av(ffmpeg, v, inp, args, chunks, fps,
-                        has_vfr, progress, effects, rules, temp, log))
+                        progress, obj_sheet, rules, temp, log))
 
         log.conwrite('Writing the output file.')
 
