@@ -1,5 +1,3 @@
-'''formats/utils.py'''
-
 def safe_mkdir(path):
     from shutil import rmtree
     from os import mkdir
@@ -16,7 +14,8 @@ def get_width_height(inp):
     else:
         return inp.video_streams[0]['width'], inp.video_streams[0]['height']
 
-def indent(base: int, *args: str) -> str:
+def indent(base, *args):
+    # type: (int, str) -> str
     r = ''
     for line in args:
         r += ('\t' * base) + line + '\n'
