@@ -1,16 +1,14 @@
-'''render/subtitle.py'''
-
 import os
 import re
 
 class SubtitleParser:
     def __init__(self):
-        self.supported_codecs = ['ass', 'webvtt', 'mov_text']
+        self.supported_codecs = ('ass', 'webvtt', 'mov_text')
 
     def parse(self, text, fps, codec):
 
         if(codec not in self.supported_codecs):
-            raise ValueError('codec {} not supported.'.format(codec))
+            raise ValueError(f'codec {codec} not supported.')
 
         self.fps = fps
         self.codec = codec
@@ -35,10 +33,9 @@ class SubtitleParser:
         self.footer = text[item.span()[1]:]
 
 
-    def edit(self, chunks, speeds):
-
+    def edit(self, chunks):
         for cut in reversed(chunks):
-            the_speed = speeds[cut[2]]
+            the_speed = cut[2]
             speed_factor = 1 if the_speed == 99999 else 1 - (1 / the_speed)
 
             new_content = []
@@ -65,7 +62,7 @@ class SubtitleParser:
 
         self.contents = new_content
 
-    def write(self, file_path):
+    def write(self, file_path: str):
         with open(file_path, 'w') as file:
             file.write(self.header)
             for item in self.contents:
@@ -78,20 +75,20 @@ class SubtitleParser:
                 ))
             file.write(self.footer)
 
-    def to_frame(self, text):
-        # type: (str) -> int
+    def to_frame(self, text: str) -> int:
         if(self.codec == 'mov_text'):
             time_format = r'(\d+):?(\d+):([\d,]+)'
         else:
             time_format = r'(\d+):?(\d+):([\d.]+)'
 
         nums = re.match(time_format, text)
+        assert nums is not None
+
         hours, minutes, seconds = nums.groups()
         seconds = seconds.replace(',', '.', 1)
         return round((int(hours) * 3600 + int(minutes) * 60 + float(seconds)) * self.fps)
 
-    def to_timecode(self, frame):
-        # type: (int) -> str
+    def to_timecode(self, frame: int) -> str:
         seconds = frame / self.fps
 
         m, s = divmod(seconds, 60)
@@ -113,7 +110,7 @@ class SubtitleParser:
         return time_format.format(int(h), int(m), s)
 
 
-def cut_subtitles(ffmpeg, inp, chunks, speeds, fps, temp, log):
+def cut_subtitles(ffmpeg, inp, chunks, fps, temp, log):
     for s, sub in enumerate(inp.subtitle_streams):
         file_path = os.path.join(temp, '{}s.{}'.format(s, sub['ext']))
         new_path = os.path.join(temp, 'new{}s.{}'.format(s, sub['ext']))
@@ -129,5 +126,5 @@ def cut_subtitles(ffmpeg, inp, chunks, speeds, fps, temp, log):
             with open(convert_path, 'r') as file:
                 parser.parse(file.read(), fps, 'webvtt')
 
-        parser.edit(chunks, speeds)
+        parser.edit(chunks)
         parser.write(new_path)
