@@ -1,9 +1,7 @@
-'''subcommands/desc.py'''
-
 import sys
 
 def desc_options(parser):
-    parser.add_argument('--ffmpeg_location', default=None,
+    parser.add_argument('--ffmpeg-location', default=None,
         help='Point to your custom ffmpeg file.')
     parser.add_argument('--help', '-h', action='store_true',
         help='Print info about the program or an option and exit.')
@@ -23,7 +21,11 @@ def main(sys_args=sys.argv[1:]):
     parser = desc_options(parser)
 
     log = Log()
-    args = parser.parse_args(sys_args, log, 'desc')
+
+    try:
+        args = parser.parse_args(sys_args)
+    except vanparse.ParserError as e:
+        log.error(str(e))
 
     ffmpeg = FFmpeg(args.ffmpeg_location, debug=False)
 
