@@ -1,5 +1,3 @@
-'''subcommands/info.py'''
-
 import sys
 import json
 import os.path
@@ -7,11 +5,11 @@ import os.path
 def info_options(parser):
     parser.add_argument('--json', action='store_true',
         help='Export the information in JSON format.')
-    parser.add_argument('--include_vfr', '--has_vfr', action='store_true',
+    parser.add_argument('--include-vfr', '--has-vfr', action='store_true',
         help='Skip information that is very slow to get.')
-    parser.add_argument('--ffmpeg_location', default=None,
+    parser.add_argument('--ffmpeg-location', default=None,
         help='Point to your custom ffmpeg file.')
-    parser.add_argument('--my_ffmpeg', action='store_true',
+    parser.add_argument('--my-ffmpeg', action='store_true',
         help='Use the ffmpeg on your PATH instead of the one packaged.')
     parser.add_argument('--help', '-h', action='store_true',
         help='Print info about the program or an option and exit.')
@@ -80,9 +78,14 @@ def main(sys_args=sys.argv[1:]):
             import av
             container = av.open(file, 'r')
             pix_fmt = container.streams.video[track].pix_fmt
+            time_base = container.streams.video[track].time_base
+
             text += f'     - pix_fmt: {pix_fmt}\n'
+            text += f'     - time_base: {time_base}\n'
 
             vid['pix_fmt'] = pix_fmt
+            vid['time_base'] = time_base
+
 
             if(stream['fps'] is not None):
                 text += '     - fps: {}\n'.format(stream['fps'])
@@ -180,8 +183,8 @@ def main(sys_args=sys.argv[1:]):
             print(text)
 
     if(args.json):
-        json_object = json.dumps(file_info, indent=4) 
-        print(json_object)       
+        json_object = json.dumps(file_info, indent=4)
+        print(json_object)
 
 if(__name__ == '__main__'):
     main()
