@@ -1,18 +1,16 @@
-'''subcommands/levels.py'''
-
 import sys
 
 def levels_options(parser):
     parser.add_argument('--kind', type=str, default='audio')
     parser.add_argument('--track', type=int, default=0,
         help='what audio/video track to get. If --kind is set to motion, track will look at video streams.')
-    parser.add_argument('--ffmpeg_location', default=None,
+    parser.add_argument('--ffmpeg-location', default=None,
         help='point to your custom ffmpeg file.')
-    parser.add_argument('--my_ffmpeg', action='store_true',
+    parser.add_argument('--my-ffmpeg', action='store_true',
         help='use the ffmpeg on your PATH instead of the one packaged.')
     parser.add_argument('--help', '-h', action='store_true',
         help='print info about the program or an option and exit.')
-    parser.add_argument('(input)', nargs='*',
+    parser.add_argument('input', nargs='*',
         help='the template')
     return parser
 
@@ -33,7 +31,11 @@ def main(sys_args=sys.argv[1:]):
     temp = tempfile.mkdtemp()
     log = Log(temp=temp)
 
-    args = parser.parse_args(sys_args, log, 'levels')
+    try:
+        args = parser.parse_args(sys_args)
+    except vanparse.ParserError as e:
+        log.error(str(e))
+
     ffmpeg = FFmpeg(args.ffmpeg_location, args.my_ffmpeg, False)
 
     inp = ffmpeg.file_info(args.input[0])
@@ -61,7 +63,7 @@ def main(sys_args=sys.argv[1:]):
 
         from auto_editor.analyze.motion import display_motion_levels
 
-        display_motion_levels(inp, width=400, dilates=2, blur=21)
+        display_motion_levels(inp.path, width=400, blur=9)
 
     log.cleanup()
 
