@@ -1,11 +1,9 @@
-'''subcommands/subdump.py'''
-
 import sys
 
 def subdump_options(parser):
-    parser.add_argument('--ffmpeg_location', default=None,
+    parser.add_argument('--ffmpeg-location', default=None,
         help='Point to your custom ffmpeg file.')
-    parser.add_argument('--my_ffmpeg', action='store_true',
+    parser.add_argument('--my-ffmpeg', action='store_true',
         help='Use the ffmpeg on your PATH instead of the one packaged.')
     parser.add_argument('--help', '-h', action='store_true',
         help='Print info about the program or an option and exit.')
@@ -29,7 +27,11 @@ def main(sys_args=sys.argv[1:]):
 
     temp = tempfile.mkdtemp()
     log = Log(temp=temp)
-    args = parser.parse_args(sys_args, log, 'subdump')
+
+    try:
+        args = parser.parse_args(sys_args)
+    except vanparse.ParserError as e:
+        log.error(str(e))
 
     ffmpeg = FFmpeg(args.ffmpeg_location, args.my_ffmpeg, debug=False)
 
