@@ -1,7 +1,5 @@
-'''subcommands/test.py'''
-
 """
-Test auto-editor and make sure everything is working.
+Run End2End and Unit Tests to make sure everything is working OK.
 """
 
 # Internal Libraries
@@ -17,7 +15,7 @@ from auto_editor.utils.func import clean_list
 import auto_editor.vanparse as vanparse
 
 def test_options(parser):
-    parser.add_argument('--ffprobe_location', default='ffprobe',
+    parser.add_argument('--ffprobe-location', default='ffprobe',
         help='point to your custom ffprobe file.')
     parser.add_argument('--only', '-n', nargs='*')
     parser.add_argument('--help', '-h', action='store_true',
@@ -495,7 +493,7 @@ def main(sys_args=None):
             [ffprobe.getResolution, '640x360'],
         )
         run_program(['testsrc.mp4', '--mark_as_loud', 'start,end', '--add_rectangle',
-            '0,30,0,200,100,300,#43FA56,10'])
+            '0,30,0,200,100,300,fill=#43FA56,stroke=10'])
         os.remove('testsrc_ALTERED.mp4')
         os.remove('testsrc.mp4')
     tester.run_test('effect_tests', effect_tests,
