@@ -1,12 +1,12 @@
-'''utils/func.py'''
-
 """
 To prevent duplicate code being pasted between scripts, common functions should be
 put here. No function should modify or create video/audio files on its own.
 """
 
+from typing import List, Tuple
+
 def get_stdout(cmd):
-    # type: (list[str]) -> str
+    # type: (List[str]) -> str
     import subprocess
     process = subprocess.Popen(cmd, stdout=subprocess.PIPE,
         stderr=subprocess.STDOUT)
@@ -23,7 +23,7 @@ def clean_list(x, rm_chars):
     return new_list
 
 def aspect_ratio(width, height):
-    # type: (int, int) -> tuple(2)
+    # type: (int, int) -> Tuple[int, int] | Tuple[None, None]
     if(height == 0):
         return None, None
 
@@ -35,14 +35,14 @@ def aspect_ratio(width, height):
     c = gcd(width, height)
     return width // c, height // c
 
-def get_new_length(chunks, speeds, fps):
-    # type: (list[list[int]], list[float | int], float) -> float
-    timeInFrames = 0
+def get_new_length(chunks, fps):
+    # type: (List[Tuple[int, int, float]], float) -> float
+    time_in_frames = 0.0
     for chunk in chunks:
         leng = chunk[1] - chunk[0]
-        if(speeds[chunk[2]] < 99999):
-            timeInFrames += leng * (1 / speeds[chunk[2]])
-    return timeInFrames / fps
+        if(chunk[2] < 99999):
+            time_in_frames += leng * (1 / chunk[2])
+    return time_in_frames / fps
 
 def human_readable_time(time_in_secs):
     # type(int | float) -> str
@@ -60,6 +60,7 @@ def human_readable_time(time_in_secs):
     return '{} {}'.format(time_in_secs, units)
 
 def open_with_system_default(path, log):
+    # type(str, Log) -> None
     from subprocess import call
     try:  # should work on Windows
         from os import startfile
@@ -77,7 +78,7 @@ def open_with_system_default(path, log):
                     log.warning('Could not open output file.')
 
 def fnone(val):
-    # type: (Any) -> bool
+    # type: (...) -> bool
     return val == 'none' or val == 'unset' or val is None
 
 def append_filename(path, val):
@@ -87,6 +88,7 @@ def append_filename(path, val):
     return root + val + ext
 
 def set_output_name(path, inp_ext, making_data_file, args):
+    # type: (...) -> str
     import os.path
     root, ext = os.path.splitext(path)
 
